local _f_init = MutatorsManager.init
function MutatorsManager:init()
    _f_init(self)
    if not self:can_mutators_be_active() then
        return
    end

    self._custom_mutators = {}
    for _, CustomMutator in ipairs(MutatorHelper.CustomMutators) do -- Add new mutators
        local m = CustomMutator:new(self)
        table.insert(self._mutators, m)
        table.insert(self._custom_mutators, m)
    end

    table.sort(self._custom_mutators, function (a, b) -- Sort them
		return b.load_priority < a.load_priority
    end)

    for _, CustomMutator in ipairs(self._custom_mutators) do -- Run them
        local id = CustomMutator._type
        local data = Global.mutators.active_on_load[id]
        if data then
            local mutator = self:get_mutator_from_id(id)
            table.insert(self:active_mutators(), {mutator = mutator})
            if Network:is_client() then
                for key, value in pairs(data) do
                    mutator:set_host_value(key, value)
                end
            end
            if mutator.setup then
                mutator:setup(self)
            end
        end
    end
end

local _f_categories = MutatorsManager.categories
function MutatorsManager:categories()
    local original_table = _f_categories(self)
    for _, category in ipairs(MutatorHelper.CustomCategories) do
        if category.count > 0 then
            table.insert(original_table, category.name)
        end
    end
    return original_table
end

function MutatorsManager:init_finalize()
    local active_mutators = Global.mutators.active_on_load
    for _, CustomMutator in ipairs(self._custom_mutators or {}) do
        if CustomMutator.init_finalize and active_mutators[CustomMutator._type] then
            CustomMutator:init_finalize()
        end
    end
end

function MutatorsManager:init_finalize_setup()
    local active_mutators = Global.mutators.active_on_load
    for _, CustomMutator in ipairs(self._custom_mutators or {}) do
        if CustomMutator.init_finalize_setup and active_mutators[CustomMutator._type] then
            CustomMutator:init_finalize_setup()
        end
    end
end